pub fn load_sessions() -> Result<Vec<Session>>
Load Claude sessions from the local Claude project store.
Returns an error when the Claude sessions directory cannot be read or a session file cannot be parsed.